diff --git a/system-contract-dapp-playground/src/app/hedera/erc-20/page.tsx b/system-contract-dapp-playground/src/app/hedera/erc-20/page.tsx
new file mode 100644
index 000000000..0d4186e67
--- /dev/null
+++ b/system-contract-dapp-playground/src/app/hedera/erc-20/page.tsx
@@ -0,0 +1,27 @@
+/*-
+ *
+ * Hedera Smart Contracts
+ *
+ * Copyright (C) 2023 Hedera Hashgraph, LLC
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ */
+
+const ERC20 = () => {
+ return (
+
ERC20
+ );
+};
+
+export default ERC20;
diff --git a/system-contract-dapp-playground/src/app/hedera/erc-721/page.tsx b/system-contract-dapp-playground/src/app/hedera/erc-721/page.tsx
new file mode 100644
index 000000000..212f7db48
--- /dev/null
+++ b/system-contract-dapp-playground/src/app/hedera/erc-721/page.tsx
@@ -0,0 +1,27 @@
+/*-
+ *
+ * Hedera Smart Contracts
+ *
+ * Copyright (C) 2023 Hedera Hashgraph, LLC
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ */
+
+const ERC721 = () => {
+ return (
+
ERC721
+ );
+};
+
+export default ERC721;
diff --git a/system-contract-dapp-playground/src/app/hedera/exchange-rate-hip-475/page.tsx b/system-contract-dapp-playground/src/app/hedera/exchange-rate-hip-475/page.tsx
new file mode 100644
index 000000000..7d487ce2a
--- /dev/null
+++ b/system-contract-dapp-playground/src/app/hedera/exchange-rate-hip-475/page.tsx
@@ -0,0 +1,27 @@
+/*-
+ *
+ * Hedera Smart Contracts
+ *
+ * Copyright (C) 2023 Hedera Hashgraph, LLC
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ */
+
+const HIP475 = () => {
+ return (
+
HIP475
+ );
+};
+
+export default HIP475;
diff --git a/system-contract-dapp-playground/src/app/hedera/hrc-719/page.tsx b/system-contract-dapp-playground/src/app/hedera/hrc-719/page.tsx
new file mode 100644
index 000000000..bd8025b96
--- /dev/null
+++ b/system-contract-dapp-playground/src/app/hedera/hrc-719/page.tsx
@@ -0,0 +1,27 @@
+/*-
+ *
+ * Hedera Smart Contracts
+ *
+ * Copyright (C) 2023 Hedera Hashgraph, LLC
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ */
+
+const HRC719 = () => {
+ return (
+
HRC719
+ );
+};
+
+export default HRC719;
diff --git a/system-contract-dapp-playground/src/app/hedera/hts-hip-206/page.tsx b/system-contract-dapp-playground/src/app/hedera/hts-hip-206/page.tsx
new file mode 100644
index 000000000..36b176b71
--- /dev/null
+++ b/system-contract-dapp-playground/src/app/hedera/hts-hip-206/page.tsx
@@ -0,0 +1,27 @@
+/*-
+ *
+ * Hedera Smart Contracts
+ *
+ * Copyright (C) 2023 Hedera Hashgraph, LLC
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ */
+
+const HTS206 = () => {
+ return (
+
HTS206
+ );
+};
+
+export default HTS206;
diff --git a/system-contract-dapp-playground/src/app/hedera/layout.tsx b/system-contract-dapp-playground/src/app/hedera/layout.tsx
new file mode 100644
index 000000000..032e415d4
--- /dev/null
+++ b/system-contract-dapp-playground/src/app/hedera/layout.tsx
@@ -0,0 +1,46 @@
+/*-
+ *
+ * Hedera Smart Contracts
+ *
+ * Copyright (C) 2023 Hedera Hashgraph, LLC
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ */
+
+import Navbar from '@/components/navbar';
+import Footer from '@/components/footer';
+import LeftSideBar from '@/components/leftSideBar';
+
+export default function RootLayout({ children }: { children: React.ReactNode }) {
+ return (
+
+
+
+ {/* */}
+
+
+
+ {/* */}
+
{children}
+
+ {/* */}
+
+
+
+
+
+
+
+ );
+}
diff --git a/system-contract-dapp-playground/src/app/(protected)/overview/page.tsx b/system-contract-dapp-playground/src/app/hedera/overview/page.tsx
similarity index 83%
rename from system-contract-dapp-playground/src/app/(protected)/overview/page.tsx
rename to system-contract-dapp-playground/src/app/hedera/overview/page.tsx
index 83af50940..72a6ea860 100644
--- a/system-contract-dapp-playground/src/app/(protected)/overview/page.tsx
+++ b/system-contract-dapp-playground/src/app/hedera/overview/page.tsx
@@ -18,12 +18,10 @@
*
*/
+import OverviewSection from '@/sections/overview';
+
const Overview = () => {
- return (
-
- Overview
-
- );
+ return ;
};
export default Overview;
diff --git a/system-contract-dapp-playground/src/app/hedera/prng-hip-351/page.tsx b/system-contract-dapp-playground/src/app/hedera/prng-hip-351/page.tsx
new file mode 100644
index 000000000..57a19c699
--- /dev/null
+++ b/system-contract-dapp-playground/src/app/hedera/prng-hip-351/page.tsx
@@ -0,0 +1,27 @@
+/*-
+ *
+ * Hedera Smart Contracts
+ *
+ * Copyright (C) 2023 Hedera Hashgraph, LLC
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ */
+
+const HIP351 = () => {
+ return (
+
HIP351
+ );
+};
+
+export default HIP351;
diff --git a/system-contract-dapp-playground/src/app/layout.tsx b/system-contract-dapp-playground/src/app/layout.tsx
index 4a66857e5..47b8fcf6f 100644
--- a/system-contract-dapp-playground/src/app/layout.tsx
+++ b/system-contract-dapp-playground/src/app/layout.tsx
@@ -20,8 +20,6 @@
import '@/styles/globals.css';
import StyreneAWebFont from '@/fonts';
-import Navbar from '@/components/navbar';
-import Footer from '@/components/footer';
import dappMetadata from '@/utils/metadata';
import ChakraUIProviders from '@/libs/chakra/provider';
import BgGradient from '@/components/background-gradients';
@@ -30,18 +28,12 @@ import BgGradient from '@/components/background-gradients';
export default function RootLayout({ children }: { children: React.ReactNode }) {
return (
-
+
-
-
-
-
- {children}
-
-
-
-
-
+
+ {children}
+
+
diff --git a/system-contract-dapp-playground/src/app/page.tsx b/system-contract-dapp-playground/src/app/page.tsx
index 95daf2272..b6a0f9c0f 100644
--- a/system-contract-dapp-playground/src/app/page.tsx
+++ b/system-contract-dapp-playground/src/app/page.tsx
@@ -17,8 +17,16 @@
* limitations under the License.
*
*/
+import Footer from '@/components/footer';
+import Navbar from '@/components/navbar';
import LandingPage from '@/sections/landing';
export default function Home() {
- return ;
+ return (
+
+
+ ;
+
+
+ );
}
diff --git a/system-contract-dapp-playground/src/components/background-gradients/index.tsx b/system-contract-dapp-playground/src/components/background-gradients/index.tsx
index 9418432de..78894e42b 100644
--- a/system-contract-dapp-playground/src/components/background-gradients/index.tsx
+++ b/system-contract-dapp-playground/src/components/background-gradients/index.tsx
@@ -21,10 +21,10 @@
const BgGradient = () => {
return (
diff --git a/system-contract-dapp-playground/src/components/leftSideBar/index.tsx b/system-contract-dapp-playground/src/components/leftSideBar/index.tsx
new file mode 100644
index 000000000..d16a6f02f
--- /dev/null
+++ b/system-contract-dapp-playground/src/components/leftSideBar/index.tsx
@@ -0,0 +1,57 @@
+'use client';
+
+/*-
+ *
+ * Hedera Smart Contracts
+ *
+ * Copyright (C) 2023 Hedera Hashgraph, LLC
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ */
+
+import Link from 'next/link';
+import { motion } from 'framer-motion';
+import { usePathname } from 'next/navigation';
+import { LEFT_SIDE_BAR_ITEMS } from '@/utils/constants';
+
+const LeftSideBar = () => {
+ const pathname = usePathname();
+
+ return (
+
+ {LEFT_SIDE_BAR_ITEMS.map((item) => (
+
+ {item.name}
+
+ ))}
+
+ );
+};
+
+export default LeftSideBar;
diff --git a/system-contract-dapp-playground/src/sections/overview/index.tsx b/system-contract-dapp-playground/src/sections/overview/index.tsx
new file mode 100644
index 000000000..10f4ba9e7
--- /dev/null
+++ b/system-contract-dapp-playground/src/sections/overview/index.tsx
@@ -0,0 +1,128 @@
+'use client';
+/*-
+ *
+ * Hedera Smart Contracts
+ *
+ * Copyright (C) 2023 Hedera Hashgraph, LLC
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ */
+
+import Link from 'next/link';
+import { motion } from 'framer-motion';
+import { LEFT_SIDE_BAR_ITEMS } from '@/utils/constants';
+
+const OverviewSection = () => {
+ return (
+
+ {/* top part */}
+
+ {/* Overview */}
+
Overview
+
+ {/* Hedera Network */}
+
+ {/* Title */}
+
Hedera Network
+
+ {/* content */}
+
+ Hedera is a fully open source public distributed ledger that utilizes the fast, fair,
+ and secure hashgraph consensus. Its network services include Solidity-based smart
+ contracts, as well as native tokenization and consensus services used to build
+ decentralized applications. Learn more about{' '}
+
+ Hedera network
+
+ !
+
+
+
+ {/* Hedera Smart Contract Library */}
+
+ {/* title */}
+
Hedera Smart Contract Library
+ {/* content */}
+
+ Seamlessly scale your projects using Solidity smart contracts on Hedera, taking
+ advantage of its unparalleled efficiency. Curious to explore the inner workings of smart
+ contracts hosted on Dapp Playground? The source code for{' '}
+
+ Hedera smart contract library
+ {' '}
+ is readily available on Github, awaiting your delve into its intricacies.
+
+
+
+
+ {/* break line */}
+
+
+ {/* bottom part */}
+
+ {/* DApp Playground */}
+
+ {/* title */}
+
DApp Playground
+ {/* content */}
+
+ An intuitively designed interface aimed at highlighting the capabilities of Hedera
+ Network's system contracts. This revolutionary platform empowers developers to
+ effortlessly deploy and engage with illustrative system contracts, simplifying the task
+ of constructing and resolving issues within decentralized applications.
+
+
+
+ {/* buttons */}
+
+
+ Here are the contracts exposed on this platform:
+
diff --git a/system-contract-dapp-playground/src/components/navbar/index.tsx b/system-contract-dapp-playground/src/components/navbar/index.tsx
index fead05791..1e050ca33 100644
--- a/system-contract-dapp-playground/src/components/navbar/index.tsx
+++ b/system-contract-dapp-playground/src/components/navbar/index.tsx
@@ -73,14 +73,18 @@ const Navbar = () => {
return (
{/* Protected Navbar */}
{isConnected ? (
-
+
{/* Logo */}
{
) : (
- <>
+
{/* Unprotected Navbar */}
{/* Logo */}
@@ -152,9 +162,11 @@ const Navbar = () => {
{/* Text logo */}
Hedera
- >
+
)}
+ {isConnected && }
+
{didWalletPop && (
{
return;
}
- // navigate user to /overview
- router.push('/overview');
+ // navigate user to /hedera/overview
+ router.push('/hedera/overview');
}
})();
}, [accounts, router, toaster, walletProvider]);
@@ -186,9 +186,9 @@ const LandingPage = () => {
{/* signature */}
Accelerate the future on Hedera